# Introduction

Keithley 2600B are a series of programmable sourcemeters.
They can be accessed remotely via a VISA interface.
The programming relies on the builtin TSP script engine which uses a LUA-style syntax.

This packet provides a python API for convenient remote programming of the SMU via Ethernet/USB.